@@ -49,7 +49,7 @@ class Gui:
         self.title.set_justify(gtk.JUSTIFY_CENTER)
             
         # Seekbar 
-        self.seek = hildon.GtkHScale()
+        self.seek = hildon.Seekbar()
         self.seek.set_range(0.0,1.0)
         self.seek.set_draw_value(False)
         self.seek.set_update_policy(gtk.UPDATE_DISCONTINUOUS) 
@@ -151,7 +151,7 @@ class Gui:
         log.info("sleep time timeout")
         hildon.hildon_banner_show_information(self.win, "", "Sleep timer")
         self.controller.stop()
-        button.set_text("Resume","Resume playing the audiobook")
+        self.button.set_text("Resume","Resume playing the audiobook")
         return False                    # do not repeat
 
     def get_help(self,button):
@@ -202,6 +202,7 @@ class Gui:
         else:
             log.debug("chapter selection sendt to controller: " + selector.get_current_text())
             self.controller.set_chapter(selector.get_current_text()) # signal controller
+            self.button.set_text("Play", "Start playing the audiobook") # reset button
 
     def sleeptimer_set(self, selector, selected):
         if self.sleep_timer is not None:
